@@ -110,6 +110,7 @@ get_cross <- function(predicted, y, positive) {
 #' In this case, the speed of visualization can be slow.
 #'
 #' @examples
+#' \donttest{
 #' library(ggplot2)
 #' library(rpart)
 #' data(kyphosis)
@@ -129,6 +130,7 @@ get_cross <- function(predicted, y, positive) {
 #' plot_cutoff(pred, kyphosis$Kyphosis, "present", type = "prob", measure = "mcc")
 #' plot_cutoff(pred, kyphosis$Kyphosis, "present", type = "prob", measure = "cross")
 #' plot_cutoff(pred, kyphosis$Kyphosis, "present", type = "prob", measure = "half")
+#' }
 #' 
 #' @import dplyr
 #' @import ggplot2
@@ -284,6 +286,7 @@ plot_cutoff <- function(predicted, y, positive, type = c("mcc", "density", "prob
 #' }
 #'
 #' @examples
+#' \donttest{
 #' library(dplyr)
 #'
 #' # Divide the train data set and the test data set.
@@ -323,6 +326,7 @@ plot_cutoff <- function(predicted, y, positive, type = c("mcc", "density", "prob
 #' # Calculate Confusion Matrix by cutoff = 0.55.
 #' performance_metric(attr(pred$predicted[[1]], "pred_prob"), test$Kyphosis,
 #'   "present", "ConfusionMatrix", cutoff = 0.55)
+#' }
 #'    
 #' @importFrom stats density
 #' @export
@@ -342,7 +346,7 @@ performance_metric <- function(pred, actual, positive,
   metric_0_1 <- c("LogLoss", "AUC", "Gini", "PRAUC", "LiftAUC", "GainAUC", "KS_Stat")
 
   if (metric %in% metric_factor) {
-    level <- levels(factor(actual))
+    level <- levels(actual)
     pred_factor <- ifelse(pred < cutoff, setdiff(level, positive), positive)
 
     ZeroOneLoss <- mean(pred_factor != actual)
